migrate_builtin_tables_to_mvs

Function migrate_builtin_tables_to_mvs 

fn migrate_builtin_tables_to_mvs(tx: &mut Transaction<'_>) -> Result<(), Error>
Update system object mappings for builtins whose type changed from table to materialized view.

Required for the work of making builtin tables views over mz_catalog_raw.