CatalogState

Struct CatalogState 

pub struct CatalogState { /* private fields */ }
The in-memory representation of the Catalog. This struct is not directly used to persist metadata to persistent storage. For persistent metadata see mz_catalog::durable::DurableCatalogState.

Serialize is implemented to create human readable dumps of the in-memory state, not for storing the contents of this struct on disk.

Implementations

Source

impl CatalogState

pub fn render_notices_core( humanizer: &dyn ExprHumanizer, now: EpochMillis, df_meta: &DataflowMetainfo<RawOptimizerNotice>, notice_ids: Vec<GlobalId>, item_id: Option<GlobalId>, ) -> DataflowMetainfo<Arc<OptimizerNotice>>

Render the raw optimizer notices in df_meta into fully-formatted OptimizerNotices, using the given humanizer to resolve object names and now as the created_at timestamp for every rendered notice.

This is the humanizer-agnostic core of Catalog::render_notices; it can be called before the new item is in the catalog by wrapping a base humanizer with an mz_repr::explain::ExprHumanizerExt that knows about the to-be-created item.

Source

impl CatalogState

pub fn resolve_builtin_table_updates( &self, builtin_table_update: Vec<BuiltinTableUpdate<&'static BuiltinTable>>, ) -> Vec<BuiltinTableUpdate<CatalogItemId>>

pub fn resolve_builtin_table_update( &self, _: BuiltinTableUpdate<&'static BuiltinTable>, ) -> BuiltinTableUpdate<CatalogItemId>

pub fn pack_depends_update( &self, depender: CatalogItemId, dependee: CatalogItemId, diff: Diff, ) -> BuiltinTableUpdate<&'static BuiltinTable>

pub fn pack_aws_connection_update( &self, connection_id: CatalogItemId, aws_config: &AwsConnection, diff: Diff, ) -> Result<BuiltinTableUpdate<&'static BuiltinTable>, Error>

pub fn pack_op_update( &self, operator: &str, func_impl_details: FuncImplCatalogDetails, diff: Diff, ) -> BuiltinTableUpdate<&'static BuiltinTable>

pub fn pack_audit_log_update( &self, event: &VersionedEvent, diff: Diff, ) -> Result<BuiltinTableUpdate<&'static BuiltinTable>, Error>

pub fn pack_storage_usage_update( &self, VersionedStorageUsage::V1: VersionedStorageUsage, diff: Diff, ) -> BuiltinTableUpdate<&'static BuiltinTable>

pub fn pack_egress_ip_update( &self, ip: &IpNet, ) -> Result<BuiltinTableUpdate<&'static BuiltinTable>, Error>

pub fn pack_license_key_update( &self, license_key: &ValidatedLicenseKey, ) -> Result<BuiltinTableUpdate<&'static BuiltinTable>, Error>

pub fn pack_all_replica_size_updates( &self, ) -> Vec<BuiltinTableUpdate<&'static BuiltinTable>>

pub fn pack_subscribe_update( &self, id: GlobalId, subscribe: &ActiveSubscribe, diff: Diff, ) -> BuiltinTableUpdate<&'static BuiltinTable>

pub fn pack_session_update( &self, conn: &ConnMeta, diff: Diff, ) -> BuiltinTableUpdate<&'static BuiltinTable>

pub fn pack_default_privileges_update( &self, default_privilege_object: &DefaultPrivilegeObject, grantee: &RoleId, acl_mode: &AclMode, diff: Diff, ) -> BuiltinTableUpdate<&'static BuiltinTable>

pub fn pack_system_privileges_update( &self, privileges: MzAclItem, diff: Diff, ) -> BuiltinTableUpdate<&'static BuiltinTable>

pub fn pack_comment_update( &self, object_id: CommentObjectId, column_pos: Option<usize>, comment: &str, diff: Diff, ) -> BuiltinTableUpdate<&'static BuiltinTable>

pub fn pack_webhook_source_update( &self, item_id: CatalogItemId, diff: Diff, ) -> BuiltinTableUpdate<&'static BuiltinTable>

pub fn pack_source_references_update( &self, source_references: &SourceReferences, diff: Diff, ) -> Vec<BuiltinTableUpdate<&'static BuiltinTable>>

Source

impl CatalogState

pub fn check_consistency(&self) -> Result<(), Box<CatalogInconsistencies>>

Checks the CatalogState to make sure we’re internally consistent.

Source

impl CatalogState

pub fn empty_test() -> Self

Returns an empty CatalogState that can be used in tests.

pub fn for_session<'a>(&'a self, session: &'a Session) -> ConnCatalog<'a>

pub fn for_sessionless_user(&self, role_id: RoleId) -> ConnCatalog<'_>

pub fn for_system_session(&self) -> ConnCatalog<'_>

pub fn transitive_uses( &self, id: CatalogItemId, ) -> impl Iterator<Item = CatalogItemId> + '_

Returns an iterator over the deduplicated identifiers of all objects this catalog entry transitively depends on (where “depends on” is meant in the sense of CatalogItem::uses, rather than CatalogItem::references).

pub fn introspection_dependencies( &self, id: CatalogItemId, ) -> Vec<CatalogItemId>

Computes the IDs of any log sources this catalog entry transitively depends on.

pub fn resolve_full_name( &self, name: &QualifiedItemName, conn_id: Option<&ConnectionId>, ) -> FullItemName

pub fn get_entry(&self, id: &CatalogItemId) -> &CatalogEntry

pub fn get_entry_by_global_id(&self, id: &GlobalId) -> CatalogCollectionEntry

pub fn get_entries( &self, ) -> impl Iterator<Item = (&CatalogItemId, &CatalogEntry)> + '_

pub fn get_temp_items( &self, conn: &ConnectionId, ) -> impl Iterator<Item = ObjectId> + '_

pub fn has_temporary_schema(&self, conn: &ConnectionId) -> bool

Returns true if a temporary schema exists for the given connection.

Temporary schemas are created lazily when the first temporary object is created for a connection, so this may return false for connections that haven’t created any temporary objects.

pub fn get_item_by_name( &self, name: &QualifiedItemName, conn_id: &ConnectionId, ) -> Option<&CatalogEntry>

pub fn get_type_by_name( &self, name: &QualifiedItemName, conn_id: &ConnectionId, ) -> Option<&CatalogEntry>

pub fn try_get_entry(&self, id: &CatalogItemId) -> Option<&CatalogEntry>

pub fn try_get_entry_by_global_id(&self, id: &GlobalId) -> Option<&CatalogEntry>

pub fn try_get_desc_by_global_id( &self, id: &GlobalId, ) -> Option<Cow<'_, RelationDesc>>

Returns the RelationDesc for a GlobalId, if the provided GlobalId refers to an object that returns rows.

pub fn get_role(&self, id: &RoleId) -> &Role

pub fn get_roles(&self) -> impl Iterator<Item = &RoleId>

pub fn get_network_policy(&self, id: &NetworkPolicyId) -> &NetworkPolicy

pub fn get_network_policies(&self) -> impl Iterator<Item = &NetworkPolicyId>

pub fn try_get_webhook_url(&self, id: &CatalogItemId) -> Option<Url>

Returns the URL for POST-ing data to a webhook source, if id corresponds to a webhook source.

Note: Identifiers for the source, e.g. item name, are URL encoded.

pub fn with_enable_for_item_parsing<T>( &mut self, f: impl FnOnce(&mut Self) -> T, ) -> T

Execute function f on self, with all “enable_for_item_parsing” feature flags enabled. Calling this method will not permanently modify any system configuration variables.

WARNING: Any modifications made to the system configuration variables in f, will be lost.

pub fn get_indexes_on( &self, id: GlobalId, cluster: ClusterId, ) -> impl Iterator<Item = (GlobalId, &Index)>

Returns all indexes on the given object and cluster known in the catalog.

pub fn get_system_configuration(&self, name: &str) -> Result<&dyn Var, Error>

Get system configuration name.

pub fn try_get_schema( &self, database_spec: &ResolvedDatabaseSpecifier, schema_spec: &SchemaSpecifier, conn_id: &ConnectionId, ) -> Option<&Schema>

Try to get a schema, returning None if it doesn’t exist.

For temporary schemas, returns None if the schema hasn’t been created yet (temporary schemas are created lazily when the first temporary object is created).

pub fn get_schema( &self, database_spec: &ResolvedDatabaseSpecifier, schema_spec: &SchemaSpecifier, conn_id: &ConnectionId, ) -> &Schema

pub fn get_mz_catalog_schema_id(&self) -> SchemaId

pub fn get_mz_catalog_unstable_schema_id(&self) -> SchemaId

pub fn get_pg_catalog_schema_id(&self) -> SchemaId

pub fn get_information_schema_id(&self) -> SchemaId

pub fn get_mz_internal_schema_id(&self) -> SchemaId

pub fn get_mz_introspection_schema_id(&self) -> SchemaId

pub fn get_mz_unsafe_schema_id(&self) -> SchemaId

pub fn system_schema_ids(&self) -> impl Iterator<Item = SchemaId> + '_

pub fn is_system_schema_id(&self, id: SchemaId) -> bool

pub fn is_system_schema_specifier(&self, spec: SchemaSpecifier) -> bool

pub fn unstable_schema_ids(&self) -> impl Iterator<Item = SchemaId> + '_

pub fn is_unstable_schema_id(&self, id: SchemaId) -> bool

pub fn is_unstable_schema_specifier(&self, spec: SchemaSpecifier) -> bool

pub fn create_temporary_schema( &mut self, conn_id: &ConnectionId, owner_id: RoleId, ) -> Result<(), Error>

Creates a new schema in the Catalog for temporary items indicated by the TEMPORARY or TEMP keywords.

pub fn resolve_builtin_table( &self, builtin: &'static BuiltinTable, ) -> CatalogItemId

Optimized lookup for a builtin table.

Panics if the builtin table doesn’t exist in the catalog.

pub fn resolve_builtin_log( &self, builtin: &'static BuiltinLog, ) -> (CatalogItemId, GlobalId)

Optimized lookup for a builtin log.

Panics if the builtin log doesn’t exist in the catalog.

pub fn resolve_builtin_source( &self, builtin: &'static BuiltinSource, ) -> CatalogItemId

Optimized lookup for a builtin storage collection.

Panics if the builtin storage collection doesn’t exist in the catalog.

pub fn resolve_builtin_object<T: TypeReference>( &self, builtin: &Builtin<T>, ) -> CatalogItemId

Optimized lookup for a builtin object.

Panics if the builtin object doesn’t exist in the catalog.

pub fn resolve_builtin_type_references( &self, builtin: &BuiltinType<NameReference>, ) -> BuiltinType<IdReference>

pub fn config(&self) -> &CatalogConfig

pub fn resolve_database( &self, database_name: &str, ) -> Result<&Database, SqlCatalogError>

pub fn resolve_schema( &self, current_database: Option<&DatabaseId>, database_name: Option<&str>, schema_name: &str, conn_id: &ConnectionId, ) -> Result<&Schema, SqlCatalogError>

pub fn resolve_system_schema(&self, name: &'static str) -> SchemaId

Optimized lookup for a system schema.

Panics if the system schema doesn’t exist in the catalog.

pub fn resolve_search_path( &self, session: &dyn SessionMetadata, ) -> Vec<(ResolvedDatabaseSpecifier, SchemaSpecifier)>

pub fn effective_search_path( &self, search_path: &[(ResolvedDatabaseSpecifier, SchemaSpecifier)], include_temp_schema: bool, ) -> Vec<(ResolvedDatabaseSpecifier, SchemaSpecifier)>

pub fn resolve_cluster(&self, name: &str) -> Result<&Cluster, SqlCatalogError>

pub fn resolve_builtin_cluster(&self, cluster: &BuiltinCluster) -> &Cluster

pub fn resolve_cluster_replica( &self, cluster_replica_name: &QualifiedReplica, ) -> Result<&ClusterReplica, SqlCatalogError>

pub fn resolve( &self, get_schema_entries: fn(&Schema) -> &BTreeMap<String, CatalogItemId>, current_database: Option<&DatabaseId>, search_path: &Vec<(ResolvedDatabaseSpecifier, SchemaSpecifier)>, name: &PartialItemName, conn_id: &ConnectionId, err_gen: fn(String) -> SqlCatalogError, ) -> Result<&CatalogEntry, SqlCatalogError>

Resolves PartialItemName into a CatalogEntry.

If name does not specify a database, the current_database is used. If name does not specify a schema, then the schemas in search_path are searched in order.

pub fn resolve_entry( &self, current_database: Option<&DatabaseId>, search_path: &Vec<(ResolvedDatabaseSpecifier, SchemaSpecifier)>, name: &PartialItemName, conn_id: &ConnectionId, ) -> Result<&CatalogEntry, SqlCatalogError>

Resolves name to a non-function CatalogEntry.

pub fn resolve_function( &self, current_database: Option<&DatabaseId>, search_path: &Vec<(ResolvedDatabaseSpecifier, SchemaSpecifier)>, name: &PartialItemName, conn_id: &ConnectionId, ) -> Result<&CatalogEntry, SqlCatalogError>

Resolves name to a function CatalogEntry.

pub fn resolve_type( &self, current_database: Option<&DatabaseId>, search_path: &Vec<(ResolvedDatabaseSpecifier, SchemaSpecifier)>, name: &PartialItemName, conn_id: &ConnectionId, ) -> Result<&CatalogEntry, SqlCatalogError>

Resolves name to a type CatalogEntry.

pub fn system_config(&self) -> &SystemVars

Return current system configuration.

pub fn system_config_mut(&mut self) -> &mut SystemVars

Return a mutable reference to the current system configuration.

pub fn dump( &self, unfinalized_shards: Option<BTreeSet<String>>, ) -> Result<String, Error>

Serializes the catalog’s in-memory state.

There are no guarantees about the format of the serialized state, except that the serialized state for two identical catalogs will compare identically.

Some consumers would like the ability to overwrite the unfinalized_shards catalog field, which they can accomplish by passing in a value of Some for the unfinalized_shards argument.

pub fn availability_zones(&self) -> &[String]

pub fn concretize_replica_location( &self, location: ReplicaLocation, allowed_sizes: &Vec<String>, allowed_availability_zones: Option<&[String]>, ) -> Result<ReplicaLocation, Error>

pub fn ensure_not_reserved_role(&self, role_id: &RoleId) -> Result<(), Error>

pub fn ensure_not_reserved_network_policy( &self, network_policy_id: &NetworkPolicyId, ) -> Result<(), Error>

pub fn ensure_grantable_role(&self, role_id: &RoleId) -> Result<(), Error>

pub fn ensure_not_system_role(&self, role_id: &RoleId) -> Result<(), Error>

pub fn ensure_not_predefined_role(&self, role_id: &RoleId) -> Result<(), Error>

pub fn storage_metadata(&self) -> &StorageMetadata

Returns a read-only view of the current StorageMetadata.

To write to this struct, you must use a catalog transaction.

pub fn source_compaction_windows( &self, ids: impl IntoIterator<Item = CatalogItemId>, ) -> BTreeMap<CompactionWindow, BTreeSet<CatalogItemId>>

For the Sources ids in ids, return their compaction windows.

pub fn comment_id_to_item_id(id: &CommentObjectId) -> Option<CatalogItemId>

pub fn get_comment_id_entry( &self, id: &CommentObjectId, ) -> Option<&CatalogEntry>

pub fn comment_id_to_audit_log_name( &self, id: CommentObjectId, conn_id: &ConnectionId, ) -> String

pub fn mock_authentication_nonce(&self) -> String